==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/test/functional/Java8andUp/src/org/openj9/resources/methodparameters/WithParams.java <==
package org.openj9.resources.methodparameters;

/*******************************************************************************
 * Copyright (c) 1998, 2018 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/


/**
 * IMPORTANT NOTE: This class needs to be compiled WITH -parameters option.
 *
 * @author fkaraman
 *
 */
public class WithParams {

	public enum MOOD {
		HAPPY,
		SAD
	}

	public class InnerClass {
	}

	public WithParams() {
	}

	public WithParams(boolean firstParam) {
	}

	public WithParams(boolean firstParam, final int secondFinalParam) {
	}

	public WithParams(boolean firstParam, final int secondFinalParam, String thirdParam) {
	}

	public void sampleMethod0() {
	}

	public void sampleMethod1(boolean firstParam) {
	}

	public void sampleMethod2(boolean firstParam, final int secondFinalParam) {
	}

	public void sampleMethod3(boolean firstParam, final int secondFinalParam, String thirdParam) {
	}
}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/test/functional/Java8andUp/src/org/openj9/resources/methodparameters/WithParams.java <==
package org.openj9.resources.methodparameters;

/*
 * Copyright IBM Corp. and others 1998
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */


/**
 * IMPORTANT NOTE: This class needs to be compiled WITH -parameters option.
 *
 * @author fkaraman
 *
 */
public class WithParams {

	public enum MOOD {
		HAPPY,
		SAD
	}

	public class InnerClass {
	}

	public WithParams() {
	}

	public WithParams(boolean firstParam) {
	}

	public WithParams(boolean firstParam, final int secondFinalParam) {
	}

	public WithParams(boolean firstParam, final int secondFinalParam, String thirdParam) {
	}

	public void sampleMethod0() {
	}

	public void sampleMethod1(boolean firstParam) {
	}

	public void sampleMethod2(boolean firstParam, final int secondFinalParam) {
	}

	public void sampleMethod3(boolean firstParam, final int secondFinalParam, String thirdParam) {
	}
}
